/*-
# MS WINDOWS-BASED MASTERBALL(tm)
#
#  wmball.h
#
###
#
#  Copyright (c) 1996 - 2006	David Albert Bagley, bagleyd@tux.org
#
#                   All Rights Reserved
#
#  Permission to use, copy, modify, and distribute this software and
#  its documentation for any purpose and without fee is hereby granted,
#  provided that the above copyright notice appear in all copies and
#  that both that copyright notice and this permission notice appear in
#  supporting documentation, and that the name of the author not be
#  used in advertising or publicity pertaining to distribution of the
#  software without specific, written prior permission.
#
#  This program is distributed in the hope that it will be "useful",
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
*/

/* Header file for wmball.c */

#define IDM_GET		100
#define IDM_WRITE	101
#define IDM_EXIT	102
#define IDM_HIDE	103
#define IDM_UNDO	200
#define IDM_REDO	201
#define IDM_CLEAR	202
#define IDM_RANDOMIZE	203
#define IDM_PRACTICE	204
#define IDM_SOLVE	205
#define IDM_ORIENTIZE	206
#define IDM_TOP		300
#define IDM_TTR		301
#define IDM_TR		302
#define IDM_RIGHT	303
#define IDM_BR		304
#define IDM_BBR		305
#define IDM_BOTTOM	306
#define IDM_BBL		307
#define IDM_BL		308
#define IDM_LEFT	309
#define IDM_TL		310
#define IDM_TTL		311
#define IDM_CW		313
#define IDM_CCW		323
#define IDM_CONTROL_TOP	340
#define IDM_CONTROL_TTR	341
#define IDM_CONTROL_TR	342
#define IDM_CONTROL_RIGHT	343
#define IDM_CONTROL_BR	344
#define IDM_CONTROL_BBR	345
#define IDM_CONTROL_BOTTOM	346
#define IDM_CONTROL_BBL	347
#define IDM_CONTROL_BL	348
#define IDM_CONTROL_LEFT	349
#define IDM_CONTROL_TL	350
#define IDM_CONTROL_TTL	351
#define IDM_CONTROL_CW	353
#define IDM_CONTROL_CCW	363
#define IDM_DEC		400
#define IDM_INC		401
#define IDM_WEDGE2	450
#define IDM_WEDGE4	451
#define IDM_WEDGE6	452
#define IDM_WEDGE8	453
#define IDM_WEDGE10	454
#define IDM_WEDGE12	455
#define IDM_ABOUT	500
#define IDM_DESCRIPTION	501
#define IDM_FEATURES	502
#define IDM_REFERENCES	503
